==> spip_4.0.4.orig.tar.xz: plugins-dist/medias/lang/medias_bg.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=bg
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'ДОБАВЯНЕ НА ДОКУМЕНТ', # MODIF
	'bouton_ajouter_image' => 'ДОБАВЯНЕ НА ИЗОБРАЖЕНИЕ', # MODIF

	// D
	'double_clic_inserer_doc' => 'Щракнете два пъти с мишката, за да вмъкнете отпратката вътре в текста',

	// E
	'entree_dimensions' => 'Размер:',
	'entree_titre_document' => 'Наименование на документа:',
	'entree_titre_image' => 'Наименование на изображението:',

	// I
	'image_tourner_180' => 'Завъртане на 180°',
	'image_tourner_droite' => 'Завъртане на 90° надясно',
	'image_tourner_gauche' => 'Завъртане на 90° наляво',
	'info_document' => 'Документ',
	'info_documents' => 'Документи',
	'info_inclusion_directe' => 'Пряко включване:',
	'info_inclusion_vignette' => 'Включване на винетка:',
	'info_installer_tous_documents' => 'Качване на всички документи',
	'info_logo_max_taille' => 'Размерът на логото трябва да е по-малък от @maxi@ пиксели (настоящият файл е @actuel@).',
	'info_portfolio' => 'Портфолио',
	'info_referencer_doc_distant' => 'Отпратка към документ, намиращ се в Интернет:',
	'info_telecharger' => 'Качете от своя компютър на сайта:',

	// T
	'texte_documents_joints' => 'Можете да разрешите добавянето на документи (файлове, изображения,
 мултимедия и др.) към статиите и/или рубриките. Тези файлове
 могат след това да се свързват като част от
 статията или да се показват отделно.', # MODIF
	'texte_documents_joints_2' => 'Настройката не възпрепятства поместването на изображения направо в статиите.', # MODIF
	'titre_documents_joints' => 'Приложени документи',
	'tout_dossier_upload' => 'Цялата папка @upload@',

	// U
	'upload_fichier_zip' => 'ZIP файл',
	'upload_fichier_zip_texte' => 'Файлът, който желаете да инсталирате е в ZIP формат.',
	'upload_fichier_zip_texte2' => 'Файлът може да бъде:',
	'upload_limit' => 'Файлът е прекалено голям за сървъра; максималната позволена големина за  <i>upload</i> е @max@.',
	'upload_zip_decompacter' => 'декомпресиран и всеки файл, който се съдържа в него ще бъде инсталиран на сайта. Файловете, които ще бъдат инсталирани са:',
	'upload_zip_telquel' => 'инсталиран както е, като ZIP файл;'
);

==> spip_4.4.8+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_bg.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=bg
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'ДОБАВЯНЕ НА ДОКУМЕНТ', # MODIF
	'bouton_ajouter_image' => 'ДОБАВЯНЕ НА ИЗОБРАЖЕНИЕ', # MODIF

	// D
	'double_clic_inserer_doc' => 'Щракнете два пъти с мишката, за да вмъкнете отпратката вътре в текста',

	// E
	'entree_dimensions' => 'Размер:',
	'entree_titre_document' => 'Наименование на документа:',
	'entree_titre_image' => 'Наименование на изображението:',

	// I
	'image_tourner_180' => 'Завъртане на 180°',
	'image_tourner_droite' => 'Завъртане на 90° надясно',
	'image_tourner_gauche' => 'Завъртане на 90° наляво',
	'info_document' => 'Документ',
	'info_documents' => 'Документи',
	'info_inclusion_directe' => 'Пряко включване:',
	'info_inclusion_vignette' => 'Включване на винетка:',
	'info_installer_tous_documents' => 'Качване на всички документи',
	'info_logo_max_taille' => 'Размерът на логото трябва да е по-малък от @maxi@ пиксели (настоящият файл е @actuel@).',
	'info_portfolio' => 'Портфолио',
	'info_referencer_doc_distant' => 'Отпратка към документ, намиращ се в Интернет:',
	'info_telecharger' => 'Качете от своя компютър на сайта:',

	// T
	'texte_documents_joints' => 'Можете да разрешите добавянето на документи (файлове, изображения,
 мултимедия и др.) към статиите и/или рубриките. Тези файлове
 могат след това да се свързват като част от
 статията или да се показват отделно.', # MODIF
	'texte_documents_joints_2' => 'Настройката не възпрепятства поместването на изображения направо в статиите.', # MODIF
	'titre_documents_joints' => 'Приложени документи',
	'tout_dossier_upload' => 'Цялата папка @upload@',

	// U
	'upload_fichier_zip' => 'ZIP файл',
	'upload_fichier_zip_texte' => 'Файлът, който желаете да инсталирате е в ZIP формат.',
	'upload_fichier_zip_texte2' => 'Файлът може да бъде:',
	'upload_limit' => 'Файлът е прекалено голям за сървъра; максималната позволена големина за  <i>upload</i> е @max@.',
	'upload_zip_decompacter' => 'декомпресиран и всеки файл, който се съдържа в него ще бъде инсталиран на сайта. Файловете, които ще бъдат инсталирани са:',
	'upload_zip_telquel' => 'инсталиран както е, като ZIP файл;',
];
